# Created: 6/5/2005
# This class is part of the 3DNAParser package

from string import join

from Basepair import Basepair
from parser_functions import contstr

__doc__ = "Class for base pairs in helices."

class BasepairH(Basepair):
    """
    This is a subclass of Basepair.

    Arguments (additional):
    o hid - the bp_id with the order of two residues in helical region
      type: tuple
    o helix_seq - helix number of the base pair
      type: int
    """
    def __init__(self, id, residue1, residue2, bp_para, iso_para,\
                 hbonds, hbond_num, bp_order, bp_label, bp_type,\
                 pat_id, hid, helix_seq):
        self.level = 'BH'
        self.hid = hid
        self.helix_seq = helix_seq
        Basepair.__init__(self, id, residue1, residue2, bp_para,\
                          iso_para, hbonds, hbond_num, bp_order,\
                          bp_label, bp_type, pat_id)

    # Public methods
    def set_helix_seq(self, helix_seq):
        "Set the helix number of the base pair."
        self.helix_seq = helix_seq

    def set_hid(self, hid):
        "Set helix id."
        self.hid = hid

    def get_helix_seq(self):
        "Get the helix number of the base pair."
        return self.helix_seq

    def get_hid(self):
        "Get helix id."
        return self.hid

    def get_secid(self):
        "Get the secondary id of the helix that this base pair is embedded"
        helix = self.get_parent()
        if helix != None:
            return helix.get_id()
        else:
            return None

    def get_hrespair(self):
        "Get residue pair with the order in helix."
        if self.id == self.hid:  # original order
            return self.residue1, self.residue2
        else:  # reversed order
            return self.residue2, self.residue1


