# Created: 12/8/2004
# This class is part of the 3DNA package

from string import join

from Entity import ChildEntity
from parser_functions import contstr

__doc__ = "Base-pair step class."

class Basestep(ChildEntity):
    """
    Basestep is a subclass of Entity.

    Arguments:
    o id - pair of base pair ids
      type: tuple
    o counter - the countering number
      type: int
    o helix_seq - helix number of the base step
      type: int
    o basepair1 - the first basepiar object forming the step
      type: BasepairH object
    o basepair2 - the second basepair object forming the step
      type: BasepairH object
    o step_para - local base-pair step parameters
      type: array
    o helix_para - local helical parameters
      type: array
    o phos_para - phosphate atoms translational parameters
      type: array
    o groove_para - groove parameters
      type: array
    o step_form - the form of local helical region
      type: string    
    """
    def __init__(self, id, counter, helix_seq, basepair1, basepair2, step_para, helix_para, phos_para, groove_para, step_form):
        self.level = "BS"
        self.counter = counter
        self.helix_seq = helix_seq
        self.basepair1 = basepair1
        self.basepair2 = basepair2
        self.step_para = step_para
        self.helix_para = helix_para
        self.phos_para = phos_para
        self.groove_para = groove_para
        self.step_form = step_form
        ChildEntity.__init__(self, id)

    # Sepcial methods
    def __repr__(self):
        ndb_id = self.get_attribute("ndb_id")
        return "<Basestep %s in %s>" % self.counter, ndb_id

    # Public methods
    def set_helix_seq(self, helix_seq):
        "Set the helix number."
        self.helix_seq = helix_seq

    def set_step_para(self, step_para):
        "Set the base-pair step parameters."
        self.step_para = step_para

    def set_helix_para(self, helix_para):
        "Set the helical parameters."
        self.helix_para = helix_para

    def set_phos_para(self, phos_para):
        "Set the phosphate translational parameters."
        self.phos_para = phos_para

    def set_groove_para(self, groove_para):
        "Set the groove parameters."
        self.groove_para = groove_para

    def set_form(self, step_form):
        "Set the step form."
        self.step_form = step_form

    def get_helix_seq(self):
        "Get the helix number."
        return self.helix_seq

    def get_step_para(self):
        "Get the base-pair step parameters."
        return self.step_para

    def get_helix_para(self):
        "Get the helical parameters."
        return self.helix_para

    def get_phos_para(self):
        "Get the phosphate translational parameters."
        return self.phos_para

    def get_groove_para(self):
        "Get the groove parameters."
        return self.groove_para

    def get_form(self):
        "Get the step form."
        return self.step_form
