# Created: 6/17/2005
# This class is part of the 3DNA package

from string import join

from Entity import Entity

__doc__ = "Class for helical regions."

class Helix(Entity):
    """
    Arguments:
    o id - secondary id (counter)
      type: int
    o sec_class - class of secondary structure, helix/unpaired
      type: string
    o element_number - the number of items
      type: int
    """
    def __init__(self, id, sec_class):
        self.level = 'H'
        self.sec_class = sec_class
        self.element_number = None
        Entity.__init__(self, id)

    # Special methods
    def __repr__(self):
        return "<Helix id = %d>" % self.id
  
    # Private methods
    def _sort(self, e1, e2):
        """
        Sort base pairs in Helix.
        BasepiarH: sort by base pair counter (helix_seq)
        """
        seq1 = e1.get_helix_seq()
        seq2 = e2.get_helix_seq()
        return cmp(seq1, seq2)
    
    # Public methods
    def sort(self):
        self.child_list.sort(self._sort)
      
    def set_sec_class(self, sec_class):
        "Set secondary class name."
        self.sec_class = sec_class

    def set_number(self, element_number):
        "Set the number of the element."
        self.element_number = element_number

    def get_sec_class(self):
        return self.sec_class
  
    def get_number(self):
        return self.element_number

    def get_chains(self):
        """
        Get two helical chains.
        Return:
        o residue list
        """
        hchain1 = []
        hchain2 = []
        for basepair in self.child_list:
            (res1, res2) = basepair.get_hrespair()
            hchain1.append(res1)
            hchain2.append(res2)
        return hchain1, hchain2

    def find_basepair(self, residue1, residue2):
        """
        Find the base pair for two given residues.
        o residue - the instance of Residue
        """
        for basepair in self.child_list:
            (res1, res2) = basepair.get_respair()
            if (res1 is residue1 and res2 is residue2) or (res1 is residue2 and res2 is residue1):
                return basepair
