# Created: 3/13/2005
# This class is part of the 3DNAParser package

# The Bio.PDB code is reused and modified for the 3DNAParser package.
########
# Copyright (C) 2002, Thomas Hamelryck (thamelry@vub.ac.be)
# This code is part of the Biopython distribution and governed by its
# license.  Please see the LICENSE file that should have been included
# as part of this package.  
########

__doc__ = "Model class in Structure objects."

from Entity import Entity

class Model(Entity):
    """
    The model record specifies the model serial number when multiple
    structures are presented in a single coordinate entry, as is often
    the case with structures determined by NMR. For crystal structure,
    there is usually one model in the entry.
    o id - model id
      type: int
    """
    def __init__(self, id):
        """
        Arguments:
        o id - interger
        starting from 1 for one model structure.
        """
        self.level = "M"
        Entity.__init__(self, id)
        
    # Special methods
    def __repr__(self):
        return "<Model ID: %s>" % self.get_id()

    # Private methods
    def _sort(self, c1, c2):
        """
        Sort the Chains instances in the Model instance.

        Chain instances are sorted alphabetically according to
        their chain id. Blank chains come last, as they often consist
        of waters.
        
        Arguments:
        o c1, c2 - Chain objects
        """
        id1 = c1.get_id()
        id2 = c2.get_id()
        # make sure blank chains come last (often waters)
        if id1 == " " and id2 != " ":
            return 1
        elif id2 == " " and id1 != " ":
            return -1
        return cmp(id1, id2)
    
