# Created: 12/7/2004
# This class is part of the 3DNA package

from string import join

from Entity import ChildEntity
from parser_functions import contstr

__doc__ = "Class for high-order base interactions."

class Multiplet(ChildEntity):
    """
    Multiplet is an object of multiple base interactions.
    
    Arguments:
    o id - tuple of residue counters
      type: tuple
    o counter - multiplet counter
      type: int
    o quanlity - perfect/partial
      type: string
    o res_num - the number of residues in the multiplet
      type: int
    o res_list - list of residue objects
      type: list
    """
    def __init__(self, id, counter, quanlity, res_num, res_list):
        self.level = "I"
        self.counter = counter
        self.quanlity = quanlity
        self.res_num = res_num
        self.res_list = res_list
        self.pat_name = None
        ChildEntity.__init__(self, id)

    # Special methods
    def __repr__(self):
        return "<Multiplet: residue counters = %s>" % str(self.id)

    # Public methods
    def set_quanlity(self, quanlity):
        "Set perfect/partial attribute to the multiplet."
        self.quanlity = quanlity

    def set_res_num(self, res_num):
        "Set the number of residues in the multiplet."
        self.res_num = res_num

    def set_res_list(self, res_list):
        "Set the residue instance list of the multiplet."
        self.res_list = res_list

    def set_pat_name(self, pat_name):
        self.pat_name = pat_name

    def get_quanlity(self):
        return self.quanlity

    def get_multi_id(self):
        "Return the id for table: ndb_id + contering number."
        full_id = self.get_full_id()
        ndb_id = full_id[0]
        multi_id = ndb_id + "_" + str(self.counter)
        return multi_id

    def get_res_num(self):
        return self.res_num

    def get_res_names(self):
        resname_list = []
        for residue in self.res_list:
            resname_list.append(residue.get_refname())
        resname_list.sort()
        return join(resname_list, '')

    def get_res_list(self):
        return self.res_list

    def get_pat_name(self):
        return self.pat_name
    
