# Created: 6/3/2005
# This class is part of the 3DNAParser package

from Entity import Entity

__doc__ = "Class for secondary structure."

class Secondary(Entity):
    """
    Secondary class is a wrapper class containing information of helices
    and unpaired regions. Its child is defined by the Element class which
    can be helix or unpaired.
    Arguments:
    o id - a label, usually using 'secondary'
      type: string
    """
    def __init__(self, id):
        self.level = 'S'
        Entity.__init__(self, id)

    # Special methods
    def __repr__(self):
        return "<Secondary element wrapper>"

    # Private methods
    def _sort(self, s1, s2):
        """
        Sort secondary elements (helices and unpaired regions)
        on the basis of the element id.
        """
        return cmp(s1.get_id(), s2.get_id())

    # Public methods
    def has_helix(self):
        "Return 1 if the structure has helices."
        for element in self.child_list:
            if element.get_sec_class() == "helix":
                return 1
        return 0

    def has_unpaired(self):
        "Return 1 if the structure has unpaired regions."
        for element in self.child_list:
            if element.get_sec_class() == "unpaired":
                return 1
        return 0
