# Created: 6/24/2005
# Variant template class

__doc__ = "VarTemplate class for base pairs."

class VarTemplate:
   """
   VarTemplate class is a subclass of Pattern, and is reprentative pattern
   for all patterns that have common hydrogen bonds.
   Standards of being a variant template:
   1. hydrogen bonds = 2
   2. not bifurcated
   """
   def __init__(self, pattern):
      self.pattern = pattern
      self.variant_list = []
      self.neighbour_list = []
      self.cluster_name = None
      
   # Public methods
   def add_variant(self, pat_name):
      "Add a new variant with given pattern name."
      if pat_name not in self.variant_list:
         self.variant_list.append(pat_name)
   
   def set_cluster_name(self, cluster_name):
      "Set cluster name."
      self.cluster_name = cluster_name

   def get_cluster_name(self):
      "Return the cluster name."
      return self.cluster_name
      
   def get_variant_list(self):
      "Return the list of variants."
      return self.variant_list
   
   def get_variant_number(self):
      "Return the number of variants for the current variant template."
      return len(self.variant_list)
   
   def get_neighbours(self):
      "Return the neighbours of the current variant template."
      return self.neighbour_list

   def get_pattern(self):
      "Return the pattern of the variant template."
      return self.pattern
   
   def get_template_name(self):
      "Return the pat_name of the template."
      return self.pattern.get_pat_name()
   
   def is_neighbour(self, template):
      "Check if two templates have common variants."
      for var in self.variant_list:
         if var in template.get_variant_list():
            return 1
      return 0
   
   def add_neighbour(self, template):
      "Add the neighbour template."
      if template not in self.neighbour_list:
         self.neighbour_list.append(template)
      
      
