# Created: 3/16/2005
# This class is part of the 3DNAParser package.

from string import join

from Entity import Entity

__doc__ = "The X3DNA informer for information produced by 3DNA software package"

class X3DNAInformer(Entity):
    """
    Levels:
    o X - X3DNAInformer
    o S - Secondary
    o H - Helix
    o BH- BasepairH
    o U - Unpaired
    o T - Tertiary
    o BU- BasepairU
    o P - StepWrapper
    o L - SHelix
    o BS - Basestep
    o M - MultiWrapper
    o I - Multiplet
    
    The class is a wrapper class at the highest hierarchy of the X3DNA
    parser package. It contains four childern wrappers, namely Secondary,
    Tertiary, StepWrapper, and MultiWrapper.

                                                 |-- (Helix) <>-- BasepairH
                  |-- Secondary <>-- Element <>--|
                  |                              |-- (Unpaired) <>-- Residue
                  |
    X3DNAInfo <>--|-- Tertiary  <>-- BasepairU
                  |
                  |-- MultiList <>-- Multiplet
                  |
                  |-- StepList  <>-- Basestep

    Arguments:
    o id - the id of the X3DNA object, usually ndb id
      type: string
    """
    def __init__(self, id):
        self.level = "X"
        Entity.__init__(self, id)

    # Special methods
    def __repr__(self):
        "Represent X3DNA Informer as its id."
        return "<X3DNA Informer id = %s>" % self.id

    # Private methods

    # Public methods
